@@ -13,23 +13,21 @@ class Normalize(Processor):
     def output_dim(self) -> int:
         return 1
 
-    def _initialize(self, **kwargs) -> None:
-        self._eps = kwargs.get("eps", 1e-8)
+    def initialize(self) -> None:
+        self._eps = self._config.get("eps", 1e-8)
 
-    def fit(self,
-            columns: np.ndarray) -> Processor:
-        self._caches["mean"], self._caches["std"] = columns.mean(), columns.std() + self._eps
+    def fit(self, columns: np.ndarray) -> Processor:
+        self._caches["mean"] = columns.mean()
+        self._caches["std"] = columns.std() + self._eps
         return self
 
-    def _process(self,
-                 columns: np.ndarray) -> np.ndarray:
+    def _process(self, columns: np.ndarray) -> np.ndarray:
         mean, std = map(self._caches.get, ["mean", "std"])
         columns -= mean
         columns /= std
         return columns
 
-    def _recover(self,
-                 processed_columns: np.ndarray) -> np.ndarray:
+    def _recover(self, processed_columns: np.ndarray) -> np.ndarray:
         mean, std = map(self._caches.get, ["mean", "std"])
         processed_columns *= std
         processed_columns += mean
