@@ -660,9 +660,12 @@ class TabularData(DataBase):
                 x, y = self.read_file(x, contains_labels=contains_labels)
         return DataTuple.with_transpose(x, y)
 
-    def _read_line(self, line: str) -> List[str]:
+    def _read_line(self, line: str) -> Optional[List[str]]:
         assert self._delim is not None
-        elements = line.strip().split(self._delim)
+        stripped = line.strip()
+        if not stripped:
+            return None
+        elements = stripped.split(self._delim)
         elements = ["nan" if not elem else elem for elem in elements]
         if self._quote_char is not None:
             num_quote = len(self._quote_char)
@@ -720,16 +723,33 @@ class TabularData(DataBase):
                 [True, ",", '"'],
             )
         else:
-            raise NotImplementedError(f"file type '{ext}' not recognized")
+            has_column_names, delim, quote_char = map(
+                set_default,
+                [self._has_column_names, self._delim, self._quote_char],
+                [False, ",", '"'],
+            )
+            self.log_msg(
+                f"detected file type '.{ext}', which is not familiar to cfdata.\n"
+                f"We'll us '{has_column_names}', '{delim}' and '{quote_char}' as our "
+                "`has_column_names`, `delim` and `quote_char` settings.",
+                self.warning_prefix,
+                verbose_level=3,
+                msg_level=logging.WARNING,
+            )
         self._delim, self._quote_char = delim, quote_char
         with open(file_path, "r") as f:
             first_row = None
             if has_column_names:
-                first_row = column_names = self._read_line(f.readline())
+                while True:
+                    first_row = column_names = self._read_line(f.readline())
+                    if column_names is not None:
+                        break
                 self._column_names = {i: name for i, name in enumerate(column_names)}
             data = []
             for line in f:
                 elements = self._read_line(line)
+                if elements is None:
+                    continue
                 if first_row is None:
                     first_row = elements
                 else:
